@@ -62,35 +62,6 @@ i18n_init (void)
   textdomain (PACKAGE_GT);
 }
 
-static char *
-get_gpgme_w32_inst_dir (void)
-{
-  char *gpg4win_dir = get_gpg4win_dir ();
-  char *tmp;
-  gpgrt_asprintf (&tmp, "%s\\bin\\gpgme-w32spawn.exe", gpg4win_dir);
-  memdbg_alloc (tmp);
-
-  if (!access(tmp, R_OK))
-    {
-      xfree (tmp);
-      gpgrt_asprintf (&tmp, "%s\\bin", gpg4win_dir);
-      memdbg_alloc (tmp);
-      xfree (gpg4win_dir);
-      return tmp;
-    }
-  xfree (tmp);
-  gpgrt_asprintf (&tmp, "%s\\gpgme-w32spawn.exe", gpg4win_dir);
-  memdbg_alloc (tmp);
-
-  if (!access(tmp, R_OK))
-    {
-      xfree (tmp);
-      return gpg4win_dir;
-    }
-  OutputDebugString("Failed to find gpgme-w32spawn.exe!");
-  return NULL;
-}
-
 /* Entry point called by DLL loader. */
 int WINAPI
 DllMain (HINSTANCE hinst, DWORD reason, LPVOID reserved)
@@ -99,21 +70,9 @@ DllMain (HINSTANCE hinst, DWORD reason, LPVOID reserved)
 
   if (reason == DLL_PROCESS_ATTACH)
     {
-      set_global_hinstance (hinst);
-
-      gpg_err_init ();
-
-      /* Set the installation directory for GpgME so that
-         it can find tools like gpgme-w32-spawn correctly. */
-      char *instdir = get_gpgme_w32_inst_dir();
-      gpgme_set_global_flag ("w32-inst-dir", instdir);
-      xfree (instdir);
-
-      /* The next call initializes subsystems of gpgme and should be
-         done as early as possible.  The actual return value (the
-         version string) is not used here.  It may be called at any
-         time later for this. */
-      gpgme_check_version (NULL);
+      /* Do not do anything in here so Outlook does not blame us
+         for a slow start. (See Screenshot in T6856 ) */
+      glob_hinst = hinst;
     }
   else if (reason == DLL_PROCESS_DETACH)
     {
@@ -306,6 +265,8 @@ read_options (void)
   opt.splitBCCMails = get_conf_bool ("splitBCCMails", 0);
   opt.combinedOpsEnabled = get_conf_bool ("combinedOpsEnabled", 0);
   opt.encryptSubject = get_conf_bool ("encryptSubject", 0);
+  opt.noSaveBeforeDecrypt = get_conf_bool ("noSaveBeforeDecrypt", 0);
+  opt.closeOnUnknownWriteEvent = get_conf_bool ("closeOnUnknownWriteEvent", 0);
 
   if (!opt.automation)
     {
@@ -338,11 +299,15 @@ read_options (void)
   opt.alwaysShowApproval = get_conf_bool ("alwaysShowApproval", 0);
 
   /* Hidden options  */
-  opt.sync_enc = get_conf_bool ("syncEnc", 0);
+  opt.sync_enc = 1; //get_conf_bool ("syncEnc", 0);
   /* Due to an issue where async encryption would leave
      unencrypted mails in the recently deleted folder on the
      server we block it. */
   opt.sync_dec = get_conf_bool ("syncDec", 0);
+
+  load_extension_value ("smimeNoCertSigErr", &val);
+  opt.smimeNoCertSigErr = val;
+  val = NULL;
 }
 
 
@@ -358,6 +323,7 @@ write_options (void)
     char *s_val;
   } table[] = {
     {"smimeHtmlWarnShown",       0, opt.smime_html_warn_shown, NULL},
+    {"draftKey",       2,        0, opt.draft_key},
     {NULL, 0, 0, NULL}
   };
   char buf[32];
